diff --git a/CHANGELOG.md b/CHANGELOG.md
index 9d40cc7865b733e1fde3e95323cb8dc31588bdfe..39f610cff12fb8efaa9a87e2b8a746f1708eb7a1 100644
--- a/CHANGELOG.md
+++ b/CHANGELOG.md
@@ -1,3 +1,12 @@
+Changes in Release 4.0.0
+=================================================================================
+
+* `run_af2` Python package:
+  * Rename command line option `--uniclust30-database-path` to
+    `--uniref30-database-path` according to the change in AF2 2.3.0
+  * Adapt `submit-af2` to newer SLURM version
+
+
 Changes in Release 3.1.1
 =================================================================================
 
diff --git a/run_af2/bin/submit-af2 b/run_af2/bin/submit-af2
index 1108268550d0ef516691276e68bbb7a8c3ff4874..b6a966864de09757383809c5a5d8c983dbc35926 100755
--- a/run_af2/bin/submit-af2
+++ b/run_af2/bin/submit-af2
@@ -66,7 +66,7 @@ shift
 FASTAFILES=$@
 
 sbatch --job-name=af2 \
-       --workdir=$(pwd) \
+       -D $(pwd) \
        --cpus-per-task=12 \
        --mem=85G \
        --qos=1week \
diff --git a/run_af2/pyproject.toml b/run_af2/pyproject.toml
index a4190d1f35c094bfc47b22a98ea85e7e976e763d..d550e432144c1f8f330d83c4049cee75509d983e 100644
--- a/run_af2/pyproject.toml
+++ b/run_af2/pyproject.toml
@@ -16,6 +16,8 @@ relative_to = ".."
 write_to = "src/run_af2/version.py"
 
 [build-system]
+# This works only with Python 3.6, for 3.7 this needs to be fixed. With
+# setuptools >=61, setup.cfg is gone (https://setuptools.pypa.io/en/latest/userguide/pyproject_config.html#configuring-setuptools-using-pyproject-toml-files)
 requires = [
     "setuptools==56",
     "wheel",
diff --git a/run_af2/src/run_af2/_shared.py b/run_af2/src/run_af2/_shared.py
index 31a46a1bc1ea5a5ef044fce176b2cdc4262e8beb..9886788d18eb277a17ebcbf24b84ae0f05b51256 100644
--- a/run_af2/src/run_af2/_shared.py
+++ b/run_af2/src/run_af2/_shared.py
@@ -61,7 +61,7 @@ def parse_af2_arguments(parser):
               `argparse.ArgumentParser.parse_args`.
     """
     db_preset_choices = {
-        "reduced_dbs": ["bfd_database_path", "uniclust30_database_path"],
+        "reduced_dbs": ["bfd_database_path", "uniref30_database_path"],
         "full_dbs": ["small_bfd_database_path"],
     }
 
@@ -155,7 +155,7 @@ def parse_af2_arguments(parser):
     af2_group.add_argument(
         "--uniref90-database-path",
         type=str,
-        help="Path to the Uniref90 database.",
+        help="Path to the UniRef90 database.",
         metavar="<PATH>",
         default=None,
     )
@@ -182,9 +182,9 @@ def parse_af2_arguments(parser):
         default=None,
     )
     af2_group.add_argument(
-        "--uniclust30-database-path",
+        "--uniref30-database-path",
         type=str,
-        help="Path to the Uniclust30 database, prefix for the HHblits search.",
+        help="Path to the UniRef30 database, prefix for the HHblits search.",
         metavar="<PATH/ PREFIX>",
         default=None,
     )
@@ -276,7 +276,7 @@ def parse_af2_arguments(parser):
 
 #  LocalWords:  argparse ArgumentParser Namespace Bioinformatics Biozentrum af
 #  LocalWords:  sublicense NONINFRINGEMENT sys cfg pylint toplevel ImportError
-#  LocalWords:  dbs bfd uniclust AlphaFold dir str metavar fasta nargs YYYY DL
+#  LocalWords:  dbs bfd uniref AlphaFold dir str metavar fasta nargs YYYY DL
 #  LocalWords:  basenames gpu ensembling casp sciCORE prog params uniref pdb
 #  LocalWords:  mgnify MGnify HHblits HHsearch mmcif pdbs args arg getattr
 #  LocalWords:  stderr
diff --git a/run_af2/src/run_af2/run_singularity.py b/run_af2/src/run_af2/run_singularity.py
index e55a9b3022a3f70d1306400b0b789415955b8c6d..efd3efac60be9753473d7b94976e6e8dd7b969ce 100644
--- a/run_af2/src/run_af2/run_singularity.py
+++ b/run_af2/src/run_af2/run_singularity.py
@@ -232,8 +232,8 @@ def run_af2_singularity_image(  # pylint: disable=too-many-arguments
     + "bfd_metaclust_clu_complete_id30_c90_final_seq.sorted_opt",
     small_bfd_database_path="/scicore/data/managed/BFD_small/"
     + "frozen_210812T135116/bfd-first_non_consensus_sequences.fasta",
-    uniclust30_database_path="/scicore/data/managed/Uniclust/"
-    + "frozen_181015T170110/uniclust30_2018_08/uniclust30_2018_08",
+    uniref30_database_path="/scicore/home/schwede/GROUP/alphafold_data/"
+    + "uniref30/UniRef30_2021_03",
     uniprot_database_path="/scicore/home/schwede/GROUP/alphafold_data/uniprot/"
     + "uniprot.fasta",
     pdb70_database_path="/scicore/data/managed/PDB70/frozen_210805T142857/pdb70",
@@ -331,9 +331,9 @@ def run_af2_singularity_image(  # pylint: disable=too-many-arguments
                                     Corresponds to small_bfd_database_path in
                                     AF2.
     :type small_bfd_database_path: :class:`str`
-    :param uniclust30_database_path: Uniclust30 database prefix. Corresponds to
-                                     uniclust30_database_path in AF2.
-    :type uniclust30_database_path: :class:`str`
+    :param uniref30_database_path: UniRef30 database prefix. Corresponds to
+                                     uniref30_database_path in AF2.
+    :type uniref30_database_path: :class:`str`
     :param uniprot_database_path: UniProt sequence file. Corresponds to
                                   uniprot_database_path in AF2. Needed for
                                   model_preset == multimer.
@@ -387,7 +387,7 @@ def run_af2_singularity_image(  # pylint: disable=too-many-arguments
     }
     if db_preset == "full_dbs":
         data_paths["bfd_database_path"] = bfd_database_path
-        data_paths["uniclust30_database_path"] = uniclust30_database_path
+        data_paths["uniref30_database_path"] = uniref30_database_path
     elif db_preset == "reduced_dbs":
         data_paths["small_bfd_database_path"] = small_bfd_database_path
     if model_preset == "multimer":
@@ -472,8 +472,8 @@ def main():
         data_paths["bfd_database_path"] = opts.bfd_database_path
     if opts.small_bfd_database_path is not None:
         data_paths["small_bfd_database_path"] = opts.bfd_database_path
-    if opts.uniclust30_database_path is not None:
-        data_paths["uniclust30_database_path"] = opts.uniclust30_database_path
+    if opts.uniref30_database_path is not None:
+        data_paths["uniref30_database_path"] = opts.uniref30_database_path
     if opts.uniprot_database_path is not None:
         data_paths["uniprot_database_path"] = opts.uniprot_database_path
     if opts.pdb70_database_path is not None:
@@ -509,5 +509,5 @@ def main():
 #  LocalWords:  AlphaFold Slurm sciCORE param FASTA Basenames RuntimeException
 #  LocalWords:  str dir snglrty tmpdir tmp argparse os ArgumentParser metavar
 #  LocalWords:  RawDescriptionHelpFormatter nargs getenv startswith ValueError
-#  LocalWords:  RuntimeError bfd BFD dbs mgnify HHblits uniclust Uniclust pdb
+#  LocalWords:  RuntimeError bfd BFD dbs mgnify HHblits uniref Uniref pdb
 #  LocalWords:  multimer seqres uniprot msas MSAs precomputed